==> ddd_2.1.1.orig.tar.gz: ddd-2.1.1.orig/ddd/tabs.h <==
// $Id: tabs.h,v 1.2 1997/04/25 06:40:55 zeller Exp $ -*- C++ -*-
// Tabulator functions

// Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of the DDD Library.
// 
// The DDD Library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// The DDD Library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Library General Public License for more details.
// 
// You should have received a copy of the GNU Library General Public
// License along with the DDD Library -- see the file COPYING.LIB.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.

#ifndef _DDD_tabs_h
#define _DDD_tabs_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"

// Replace first '\t' by filling up spaces until POS is reached
void tabto(string& s, int pos);

// Replace all '\t' by filling up spaces until multiple of TAB_WIDTH is reached
void untabify(string& str, int tab_width = 8);

#endif // _DDD_tabs_h
// DON'T ADD ANYTHING BEHIND THIS #endif

==> ddd-2.2.3.tar.gz: ddd-2.2.3/ddd/tabs.h <==
// $Id: tabs.h,v 1.4 1997/10/03 10:41:49 zeller Exp $ -*- C++ -*-
// Tabulator functions

// Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of the DDD Library.
// 
// The DDD Library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// The DDD Library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Library General Public License for more details.
// 
// You should have received a copy of the GNU Library General Public
// License along with the DDD Library -- see the file COPYING.LIB.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.

#ifndef _DDD_tabs_h
#define _DDD_tabs_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"

// Replace first '\t' by filling up spaces until POS is reached
void tabto(string& s, int pos);

// Replace all '\t' by filling up spaces until multiple of TAB_WIDTH
// is reached; ignore first INDENT characters.
void untabify(string& str, int tab_width = 8, int indent = 0);

#endif // _DDD_tabs_h
// DON'T ADD ANYTHING BEHIND THIS #endif
